weblogolib.GhostscriptAPI

Package weblogolib :: Class GhostscriptAPI |

# Class GhostscriptAPI

source code

    object --+
             |
            GhostscriptAPI

    Interface to the command line program Ghostscript ('gs')

Instance Methods
__init__(self, path=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
version(self) | source code
convert(self, format, fin, fout, width, height, resolution=300) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables
| formats = `'png', 'pdf', 'jpeg'`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, path=None) (Constructor) | source code
    x.__init__(...) initializes x; see x.__class__.__doc__ for signature
Overrides: object.__init__ (inherited documentation)